==> google-cloud-aiplatform-0.4.0.tar.gz: google-cloud-aiplatform-0.4.0/google/cloud/aiplatform_v1beta1/services/migration_service/pagers.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple

from google.cloud.aiplatform_v1beta1.types import migratable_resource
from google.cloud.aiplatform_v1beta1.types import migration_service


class SearchMigratableResourcesPager:
    """A pager for iterating through ``search_migratable_resources`` requests.

    This class thinly wraps an initial
    :class:`~.migration_service.SearchMigratableResourcesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``migratable_resources`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchMigratableResources`` requests and continue to iterate
    through the ``migratable_resources`` field on the
    corresponding responses.

    All the usual :class:`~.migration_service.SearchMigratableResourcesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., migration_service.SearchMigratableResourcesResponse],
        request: migration_service.SearchMigratableResourcesRequest,
        response: migration_service.SearchMigratableResourcesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.migration_service.SearchMigratableResourcesRequest`):
                The initial request object.
            response (:class:`~.migration_service.SearchMigratableResourcesResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = migration_service.SearchMigratableResourcesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[migration_service.SearchMigratableResourcesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[migratable_resource.MigratableResource]:
        for page in self.pages:
            yield from page.migratable_resources

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchMigratableResourcesAsyncPager:
    """A pager for iterating through ``search_migratable_resources`` requests.

    This class thinly wraps an initial
    :class:`~.migration_service.SearchMigratableResourcesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``migratable_resources`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``SearchMigratableResources`` requests and continue to iterate
    through the ``migratable_resources`` field on the
    corresponding responses.

    All the usual :class:`~.migration_service.SearchMigratableResourcesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[migration_service.SearchMigratableResourcesResponse]
        ],
        request: migration_service.SearchMigratableResourcesRequest,
        response: migration_service.SearchMigratableResourcesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.migration_service.SearchMigratableResourcesRequest`):
                The initial request object.
            response (:class:`~.migration_service.SearchMigratableResourcesResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = migration_service.SearchMigratableResourcesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterable[migration_service.SearchMigratableResourcesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[migratable_resource.MigratableResource]:
        async def async_generator():
            async for page in self.pages:
                for response in page.migratable_resources:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google-cloud-aiplatform-0.5.0.tar.gz: google-cloud-aiplatform-0.5.0/google/cloud/aiplatform_v1beta1/services/migration_service/pagers.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple

from google.cloud.aiplatform_v1beta1.types import migratable_resource
from google.cloud.aiplatform_v1beta1.types import migration_service


class SearchMigratableResourcesPager:
    """A pager for iterating through ``search_migratable_resources`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``migratable_resources`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchMigratableResources`` requests and continue to iterate
    through the ``migratable_resources`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., migration_service.SearchMigratableResourcesResponse],
        request: migration_service.SearchMigratableResourcesRequest,
        response: migration_service.SearchMigratableResourcesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = migration_service.SearchMigratableResourcesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[migration_service.SearchMigratableResourcesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[migratable_resource.MigratableResource]:
        for page in self.pages:
            yield from page.migratable_resources

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchMigratableResourcesAsyncPager:
    """A pager for iterating through ``search_migratable_resources`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``migratable_resources`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``SearchMigratableResources`` requests and continue to iterate
    through the ``migratable_resources`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[migration_service.SearchMigratableResourcesResponse]
        ],
        request: migration_service.SearchMigratableResourcesRequest,
        response: migration_service.SearchMigratableResourcesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = migration_service.SearchMigratableResourcesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterable[migration_service.SearchMigratableResourcesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[migratable_resource.MigratableResource]:
        async def async_generator():
            async for page in self.pages:
                for response in page.migratable_resources:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
